@@ -191,24 +191,18 @@ func (m *Manager) getLocalProtocolServer() (bertyprotocol.Service, error) {
 			return nil, errcode.TODO.Wrap(err)
 		}
 
-		rendezvousRotationBase, err := m.GetRendezvousRotationBase()
-		if err != nil {
-			return nil, errcode.ErrDeserialization.Wrap(err)
-		}
-
 		// initialize new protocol client
 		opts := bertyprotocol.Opts{
-			Host:                   m.Node.Protocol.ipfsNode.PeerHost,
-			PubSub:                 m.Node.Protocol.pubsub,
-			TinderDriver:           m.Node.Protocol.discovery,
-			IpfsCoreAPI:            m.Node.Protocol.ipfsAPI,
-			Logger:                 logger,
-			RootDatastore:          rootDS,
-			DeviceKeystore:         deviceKS,
-			OrbitDB:                odb,
-			PushKey:                pushKey,
-			GRPCInsecureMode:       m.Node.Protocol.ServiceInsecureMode,
-			RendezvousRotationBase: rendezvousRotationBase,
+			Host:             m.Node.Protocol.ipfsNode.PeerHost,
+			PubSub:           m.Node.Protocol.pubsub,
+			TinderDriver:     m.Node.Protocol.discovery,
+			IpfsCoreAPI:      m.Node.Protocol.ipfsAPI,
+			Logger:           logger,
+			RootDatastore:    rootDS,
+			DeviceKeystore:   deviceKS,
+			OrbitDB:          odb,
+			PushKey:          pushKey,
+			GRPCInsecureMode: m.Node.Protocol.ServiceInsecureMode,
 		}
 
 		m.Node.Protocol.server, err = bertyprotocol.New(m.getContext(), opts)
@@ -318,6 +312,13 @@ func (m *Manager) GetAccountStorageKey() ([]byte, error) {
 	return accountutils.GetOrCreateStorageKeyForAccount(m.nativeKeystore, m.accountID)
 }
 
+func (m *Manager) GetAccountStorageSalt() ([]byte, error) {
+	if m.nativeKeystore == nil {
+		return nil, nil
+	}
+	return accountutils.GetOrCreateStorageSaltForAccount(m.nativeKeystore, m.accountID)
+}
+
 func (m *Manager) SetLifecycleManager(manager *lifecycle.Manager) {
 	m.mutex.Lock()
 	defer m.mutex.Unlock()
