@@ -7,6 +7,7 @@ import (
 	"fmt"
 	"io"
 	"io/ioutil"
+	"math"
 	"net"
 	"net/url"
 	"os"
@@ -686,10 +687,16 @@ func (svc *service) ConversationCreate(ctx context.Context, req *messengertypes.
 		if err != nil {
 			return nil, err
 		}
-		_, err = svc.protocolClient.AppMessageSend(ctx, &protocoltypes.AppMessageSend_Request{GroupPK: ginfo.GetGroup().GetPublicKey(), Payload: am})
+		gpk := ginfo.GetGroup().GetPublicKey()
+		reply, err := svc.protocolClient.AppMessageSend(ctx, &protocoltypes.AppMessageSend_Request{GroupPK: gpk, Payload: am})
 		if err != nil {
 			return nil, err
 		}
+		cid, err := ipfscid.Cast(reply.GetCID())
+		if err != nil {
+			return nil, errcode.ErrDeserialization.Wrap(err)
+		}
+		go svc.interactionDelayedActions(cid, gpk)
 	}
 
 	go svc.autoReplicateGroupOnAllServers(pk)
@@ -1452,6 +1459,85 @@ func (svc *service) ConversationLoad(ctx context.Context, request *messengertype
 	return &messengertypes.ConversationLoad_Reply{}, nil
 }
 
+func (svc *service) ConversationMute(ctx context.Context, request *messengertypes.ConversationMute_Request) (*messengertypes.ConversationMute_Reply, error) {
+	if request.MuteForever {
+		request.MutedUntil = math.MaxInt64
+	}
+
+	if (request.Unmute && request.MutedUntil > 0) || (!request.Unmute && request.MutedUntil <= 0) {
+		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("can't mute and unmute a conversation simultaneously"))
+	}
+
+	if request.Unmute {
+		request.MutedUntil = 0
+	}
+
+	if err := svc.db.MuteConversation(request.GroupPK, request.MutedUntil); err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	conversation, err := svc.db.GetConversationByPK(request.GroupPK)
+	if err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	if err := svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypeConversationUpdated, &messengertypes.StreamEvent_ConversationUpdated{Conversation: conversation}, false); err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	return &messengertypes.ConversationMute_Reply{}, nil
+}
+
+func (svc *service) AccountPushConfigure(ctx context.Context, request *messengertypes.AccountPushConfigure_Request) (*messengertypes.AccountPushConfigure_Reply, error) {
+	updatedFields := map[string]interface{}{}
+
+	switch {
+	case !request.Unmute && request.MutedUntil <= 0 && !request.MuteForever:
+		break
+	case (request.MuteForever || request.MutedUntil > 0) && request.Unmute:
+		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("can't mute and unmute a conversation simultaneously"))
+	case request.MutedUntil > 0:
+		updatedFields["muted_until"] = request.MutedUntil
+	case request.MuteForever:
+		updatedFields["muted_until"] = int64(math.MaxInt64)
+	case request.Unmute:
+		updatedFields["muted_until"] = 0
+	}
+
+	switch {
+	case request.HidePushPreviews && request.ShowPushPreviews:
+		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("can't hide and show a push previews simultaneously"))
+	case request.HidePushPreviews:
+		updatedFields["hide_push_previews"] = true
+	case request.ShowPushPreviews:
+		updatedFields["hide_push_previews"] = false
+	}
+
+	switch {
+	case request.HideInAppNotifications && request.ShowInAppNotifications:
+		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("can't hide and show in app notifications simultaneously"))
+	case request.HideInAppNotifications:
+		updatedFields["hide_in_app_notifications"] = true
+	case request.ShowInAppNotifications:
+		updatedFields["hide_in_app_notifications"] = false
+	}
+
+	if err := svc.db.UpdateAccountFields(updatedFields); err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	account, err := svc.db.GetAccount()
+	if err != nil {
+		return nil, errcode.ErrInternal.Wrap(err)
+	}
+
+	if err := svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypeAccountUpdated, &messengertypes.StreamEvent_AccountUpdated{Account: account}, false); err != nil {
+		return nil, errcode.TODO.Wrap(err)
+	}
+
+	return &messengertypes.AccountPushConfigure_Reply{}, nil
+}
+
 func (svc *service) MediaGetRelated(ctx context.Context, request *messengertypes.MediaGetRelated_Request) (*messengertypes.MediaGetRelated_Reply, error) {
 	media, err := svc.db.GetNextMedia(request.CID, messengerdb.NextMediaOpts{
 		FileNames: request.FileNames,
@@ -1671,7 +1757,7 @@ func (svc *service) interactionDelayedActions(id ipfscid.Cid, groupPK []byte) {
 		return
 	}
 
-	if i.Type != messengertypes.AppMessage_TypeUserMessage {
+	if i.Type != messengertypes.AppMessage_TypeUserMessage && i.Type != messengertypes.AppMessage_TypeGroupInvitation {
 		// Nothing to do, move along
 		svc.logger.Debug("push: nothing to send, invalid interaction type", logutil.PrivateString("cid", id.String()), zap.String("type", i.Type.String()))
 		return
