@@ -1,12 +1,14 @@
+import { Icon } from '@ui-kitten/components'
 import React from 'react'
 import { View } from 'react-native'
-import { Text, Icon } from '@ui-kitten/components'
 
-import { useStyles } from '@berty-tech/styles'
-import { useThemeColor } from '@berty-tech/store/hooks'
+import { useStyles } from '@berty/contexts/styles'
+import { useThemeColor } from '@berty/store/hooks'
+
+import { UnifiedText } from '../shared-components/UnifiedText'
 
 export const ImageCounter: React.FC<{ count: number }> = ({ count }) => {
-	const [{ border, padding }] = useStyles()
+	const { border, padding } = useStyles()
 	const colors = useThemeColor()
 
 	return (
@@ -23,14 +25,14 @@ export const ImageCounter: React.FC<{ count: number }> = ({ count }) => {
 			]}
 		>
 			<Icon name='plus' width={22} height={22} fill={colors['reverted-main-text']} />
-			<Text
+			<UnifiedText
 				style={{
 					color: colors['reverted-main-text'],
 					fontSize: 18,
 				}}
 			>
 				{count}
-			</Text>
+			</UnifiedText>
 		</View>
 	)
 }
