@@ -1,17 +1,18 @@
 import React from 'react'
 import { View } from 'react-native'
-import { Text } from '@ui-kitten/components'
 
-import { MessageSystemWrapper } from '@berty-tech/components/chat/message/MessageSystemWrapper'
-import { ChatDate } from '@berty-tech/components/chat/common'
-import { useStyles } from '@berty-tech/styles'
-import beapi from '@berty-tech/api'
-import { useThemeColor } from '@berty-tech/store/hooks'
+import beapi from '@berty/api'
+import { ChatDate } from '@berty/components/chat/ChatDate'
+import { MessageSystemWrapper } from '@berty/components/chat/message/MessageSystemWrapper'
+import { useStyles } from '@berty/contexts/styles'
+import { useThemeColor } from '@berty/store/hooks'
+
+import { UnifiedText } from '../shared-components/UnifiedText'
 
 export const InfosMultiMember: React.FC<beapi.messenger.IConversation> = ({
 	createdDate: createdDateStr,
 }) => {
-	const [{ margin, text, flex }] = useStyles()
+	const { margin, text, flex } = useStyles()
 	const colors = useThemeColor()
 	const createdDate = parseInt(createdDateStr as unknown as string, 10)
 	const textColor = colors['background-header']
@@ -19,7 +20,9 @@ export const InfosMultiMember: React.FC<beapi.messenger.IConversation> = ({
 		<View style={[flex.align.center, flex.justify.center]}>
 			<ChatDate date={createdDate} />
 			<MessageSystemWrapper styleContainer={[margin.top.large, margin.bottom.medium]}>
-				<Text style={[text.align.center, { color: textColor }]}>Group joined! 👍</Text>
+				<UnifiedText style={[text.align.center, { color: textColor }]}>
+					Group joined! 👍
+				</UnifiedText>
 			</MessageSystemWrapper>
 		</View>
 	)
