@@ -1,60 +1,52 @@
-import React, { useState } from 'react'
-import { View, TouchableOpacity, Animated } from 'react-native'
-import { SHA3 } from 'sha3'
+import { Icon } from '@ui-kitten/components'
 import palette from 'google-palette'
-import { Text, Icon } from '@ui-kitten/components'
-import Popover from 'react-native-popover-view'
-import { PanGestureHandler, State } from 'react-native-gesture-handler'
+import React, { useCallback, useState } from 'react'
 import { useTranslation } from 'react-i18next'
+import { View, TouchableOpacity, Animated } from 'react-native'
+import { PanGestureHandler, State } from 'react-native-gesture-handler'
+import { SHA3 } from 'sha3'
 
-import beapi from '@berty-tech/api'
-import {
-	useMessengerContext,
-	useThemeColor,
-	InteractionUserMessage,
-	ParsedInteraction,
-	pbDateToNum,
-	useMessengerClient,
-} from '@berty-tech/store'
-import { useStyles } from '@berty-tech/styles'
+import beapi from '@berty/api'
+import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
+import { useModal } from '@berty/contexts/modal.context'
+import { useStyles } from '@berty/contexts/styles'
 import {
+	useAppDispatch,
 	useAppSelector,
 	useInteractionAuthor,
 	useLastConvInteraction,
-} from '@berty-tech/react-redux'
-import { selectInteraction } from '@berty-tech/redux/reducers/messenger.reducer'
+	usePlaySound,
+} from '@berty/hooks'
+import { setActiveReplyInteraction } from '@berty/redux/reducers/chatInputs.reducer'
+import { selectInteraction } from '@berty/redux/reducers/messenger.reducer'
+import {
+	useThemeColor,
+	InteractionUserMessage,
+	ParsedInteraction,
+	useMessengerClient,
+} from '@berty/store'
+import { pbDateToNum } from '@berty/utils/convert/time'
+import { getMediaTypeFromMedias } from '@berty/utils/messenger/media'
 
 import { MemberAvatar } from '../../avatars'
-import { HyperlinkUserMessage, TimestampStatusUserMessage } from './UserMessageComponents'
-import { PictureMessage } from './PictureMessage'
+import { UnifiedText } from '../../shared-components/UnifiedText'
+import { MessageMenu } from '../modals/MessageMenu.modal'
 import { AudioMessage } from './AudioMessage'
 import { FileMessage } from './FileMessage'
-import { useReplyReaction } from '../ReplyReactionContext'
-import PopoverView from './Popover'
-import { getEmojiByName, getMediaTypeFromMedias } from '../../utils'
+import { PictureMessage } from './PictureMessage'
+import { HyperlinkUserMessage, TimestampStatusUserMessage } from './UserMessageComponents'
+// We have delete this component cause unusable but we can find it here if we need: https://github.com/berty/berty/blob/38913ed828/js/packages/components/chat/message/Reactions.tsx
+// and a component dependencie https://github.com/berty/berty/blob/38913ed828f11799bb5f4471d1cb31dc182d9ed5/js/packages/components/shared-components/AnimatedNumber.tsx
+// import { Reactions } from './Reactions'
+
+// import { EmojiKeyboard } from '../modals/EmojiKeyboard.modal'
 
 const pal = palette('tol-rainbow', 256)
 const AVATAR_SIZE = 30
 const AVATAR_SPACE_RIGHT = 5
 
-const getPositionStyleForReactionView = (
-	messageWidth: number,
-	reactionWidth: number,
-	isMine: boolean,
-) => {
-	if (messageWidth - reactionWidth > 15 || isMine) {
-		return {
-			right: 15,
-		}
-	} else {
-		return {
-			left: messageWidth - 15,
-		}
-	}
-}
-
 const useStylesMessage = () => {
-	const [{ row, text, width }] = useStyles()
+	const { row, text, width } = useStyles()
 	return {
 		isMeMessage: [row.item.bottom, { maxWidth: '90%' }],
 		isOtherMessage: [row.item.top, { maxWidth: '90%' }],
@@ -179,23 +171,17 @@ export const UserMessage: React.FC<{
 	)
 	const repliedTo = useInteractionAuthor(replyOf?.conversationPublicKey || '', replyOf?.cid || '')
 	const _styles = useStylesMessage()
-	const ctx = useMessengerContext()
+	const playSound = usePlaySound()
 	const client = useMessengerClient()
-	const [{ row, margin, padding, column, text, border }, { scaleSize }] = useStyles()
+	const { row, margin, padding, column, text, border } = useStyles()
+	const { scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 	const { t } = useTranslation()
 	const [animatedValue] = useState(new Animated.Value(0))
-	const [messageLayoutWidth, setMessageLayoutWidth] = useState(0)
-	const [reactionLayoutWidth, setReactionLayoutWidth] = useState(0)
-
-	const {
-		activePopoverCid,
-		setActivePopoverCid,
-		setActiveReplyInte,
-		setActiveEmojiKeyboardCid,
-		highlightCid,
-		setHighlightCid,
-	} = useReplyReaction()
+	// const [messageLayoutWidth, setMessageLayoutWidth] = useState(0)
+	const { show } = useModal()
+	const dispatch = useAppDispatch()
+	const [highlightCid, setHighlightCid] = useState<string | undefined | null>()
 
 	const {
 		name,
@@ -214,23 +200,47 @@ export const UserMessage: React.FC<{
 		replyOf &&
 		getUserMessageState(replyOf, members, convKind, undefined, undefined, colors)
 
-	const togglePopover = () => {
+	const handleSelectEmoji = useCallback(
+		(emoji: string, remove: boolean = false) => {
+			client
+				?.interact({
+					conversationPublicKey: convPK,
+					type: beapi.messenger.AppMessage.Type.TypeUserReaction,
+					payload: beapi.messenger.AppMessage.UserReaction.encode({
+						emoji,
+						state: !remove,
+					}).finish(),
+					targetCid: inte?.cid,
+				})
+				.then(() => {
+					playSound('messageSent')
+				})
+				.catch((e: unknown) => {
+					console.warn('e sending message:', e)
+				})
+		},
+		[client, convPK, playSound, inte?.cid],
+	)
+
+	const isHighlight = highlightCid === inte.cid
+
+	const togglePopover = useCallback(() => {
 		if (inte.isMine) {
 			return
 		}
-		if (activePopoverCid === inte.cid) {
-			setActivePopoverCid(null)
-		} else if ((animatedValue as any)._value === 0) {
-			setActivePopoverCid(inte.cid)
-		}
-		Animated.timing(animatedValue, {
-			toValue: 0,
-			duration: 50,
-			useNativeDriver: false,
-		}).start(() => {})
-	}
-
-	const isHighlight = highlightCid === inte.cid
+		show(
+			<MessageMenu
+				convPk={convPK}
+				cid={inte.cid!}
+				onSelectEmoji={handleSelectEmoji}
+				replyInteraction={{
+					...inte,
+					backgroundColor: msgBackgroundColor,
+					textColor: msgTextColor,
+				}}
+			/>,
+		)
+	}, [convPK, handleSelectEmoji, inte, msgBackgroundColor, msgTextColor, show])
 
 	return (
 		<View
@@ -264,16 +274,16 @@ export const UserMessage: React.FC<{
 				<View style={{ alignItems: inte?.isMine ? 'flex-end' : 'flex-start' }}>
 					{!inte.isMine && isGroup && !isFollowupMessage && (
 						<View style={[isFollowedMessage && margin.left.scale(40)]}>
-							<Text
+							<UnifiedText
 								style={[
-									text.bold.medium,
+									text.bold,
 									margin.bottom.tiny,
 									_styles.personNameInGroup,
 									{ color: msgSenderColor },
 								]}
 							>
 								{name}
-							</Text>
+							</UnifiedText>
 						</View>
 					)}
 
@@ -300,14 +310,14 @@ export const UserMessage: React.FC<{
 									zIndex: 2,
 								}}
 							>
-								<Text
+								<UnifiedText
 									numberOfLines={1}
-									style={{ color: colors['background-header'], fontSize: 10 }}
+									style={[text.size.tiny, { color: colors['background-header'] }]}
 								>
 									<>
 										{t('chat.reply.replied-to')} {repliedTo?.displayName || ''}
 									</>
-								</Text>
+								</UnifiedText>
 							</View>
 
 							<TouchableOpacity
@@ -329,16 +339,16 @@ export const UserMessage: React.FC<{
 									},
 								]}
 							>
-								<Text
+								<UnifiedText
 									numberOfLines={1}
-									style={{ color: repliedToColors?.msgTextColor, fontSize: 10, lineHeight: 17 }}
+									style={[text.size.tiny, { color: repliedToColors?.msgTextColor, lineHeight: 17 }]}
 								>
 									{(replyOf?.type === beapi.messenger.AppMessage.Type.TypeUserMessage &&
 										replyOf?.payload?.body) ||
 										`${t('chat.reply.response-to')} ${t(
-											`medias.${getMediaTypeFromMedias(replyOf?.medias)}`,
+											`chat.shared-medias.${getMediaTypeFromMedias(replyOf?.medias)}`,
 										)}`}
-								</Text>
+								</UnifiedText>
 							</TouchableOpacity>
 						</View>
 					)}
@@ -365,11 +375,16 @@ export const UserMessage: React.FC<{
 							onHandlerStateChange={event => {
 								if (event.nativeEvent.oldState === State.ACTIVE) {
 									if (event.nativeEvent.translationX > 120) {
-										setActiveReplyInte({
-											...inte,
-											backgroundColor: msgBackgroundColor,
-											textColor: msgTextColor,
-										})
+										dispatch(
+											setActiveReplyInteraction({
+												convPK,
+												activeReplyInteraction: {
+													...inte,
+													backgroundColor: msgBackgroundColor,
+													textColor: msgTextColor,
+												},
+											}),
+										)
 										Animated.timing(animatedValue, {
 											toValue: 0,
 											duration: 50,
@@ -420,176 +435,98 @@ export const UserMessage: React.FC<{
 										width={30}
 										fill={colors['negative-asset']}
 										onPress={() => {
-											setActiveReplyInte({
-												...inte,
-												backgroundColor: msgBackgroundColor,
-												textColor: msgTextColor,
-											})
-											setActivePopoverCid(null)
-											Animated.timing(animatedValue, {
-												toValue: 0,
-												duration: 100,
-												useNativeDriver: false,
-											}).start()
+											dispatch(
+												setActiveReplyInteraction({
+													convPK,
+													activeReplyInteraction: {
+														...inte,
+														backgroundColor: msgBackgroundColor,
+														textColor: msgTextColor,
+													},
+												}),
+											)
 										}}
 									/>
 								</Animated.View>
-								<Popover
-									isVisible={activePopoverCid === inte.cid}
-									popoverStyle={{
-										backgroundColor: 'transparent',
-										borderWidth: 0,
-										shadowColor: 'transparent',
-									}}
-									backgroundStyle={{ backgroundColor: 'transparent' }}
-									arrowStyle={{ backgroundColor: 'transparent' }}
-									onRequestClose={() => {
-										setActivePopoverCid(null)
-									}}
-									from={
-										<TouchableOpacity
-											onLayout={event => {
-												setMessageLayoutWidth(event.nativeEvent.layout.width)
-											}}
-											disabled={inte.isMine}
-											activeOpacity={0.9}
-											onLongPress={togglePopover}
-											style={{ marginBottom: inte?.reactions?.length ? 10 : 0 }}
-										>
-											<>
-												{!!inte.medias?.length && (
-													<View
-														style={[
-															isFollowedMessage && {
-																marginLeft: (AVATAR_SIZE + AVATAR_SPACE_RIGHT) * scaleSize,
-															},
-															previousMessage?.medias?.[0]?.mimeType
-																? margin.top.tiny
-																: margin.top.small,
-															nextMessage?.medias?.[0]?.mimeType
-																? margin.bottom.tiny
-																: margin.bottom.small,
-														]}
-													>
-														{(() => {
-															if (inte.medias[0]?.mimeType?.startsWith('image')) {
-																return (
-																	<PictureMessage
-																		medias={inte.medias}
-																		onLongPress={togglePopover}
-																		isHighlight={isHighlight}
-																	/>
-																)
-															} else if (inte.medias[0]?.mimeType?.startsWith('audio')) {
-																return (
-																	<AudioMessage
-																		medias={inte.medias}
-																		onLongPress={togglePopover}
-																		isHighlight={isHighlight}
-																		isMine={!!inte.isMine}
-																	/>
-																)
-															} else {
-																return (
-																	<FileMessage
-																		medias={inte.medias}
-																		onLongPress={togglePopover}
-																		isHighlight={isHighlight}
-																	/>
-																)
-															}
-														})()}
-													</View>
-												)}
-												{!!(!inte.medias?.length || inte.payload?.body) && (
-													<HyperlinkUserMessage
-														inte={inte}
-														msgBorderColor={msgBorderColor}
-														isFollowedMessage={isFollowedMessage}
-														msgBackgroundColor={msgBackgroundColor}
-														msgTextColor={msgTextColor}
-														isHighlight={isHighlight}
-													/>
-												)}
-											</>
-										</TouchableOpacity>
-									}
+								<TouchableOpacity
+									// onLayout={event => {
+									// 	setMessageLayoutWidth(event.nativeEvent.layout.width)
+									// }}
+									disabled={inte.isMine}
+									activeOpacity={0.9}
+									onLongPress={togglePopover}
+									style={{ marginBottom: inte?.reactions?.length ? 10 : 0 }}
 								>
-									<PopoverView
-										onReply={() => {
-											setActivePopoverCid(null)
-											setTimeout(() => {
-												setActiveReplyInte({
-													...inte,
-													backgroundColor: msgBackgroundColor,
-													textColor: msgTextColor,
-												})
-											}, 500)
-										}}
-										onEmojiKeyboard={() => {
-											setActivePopoverCid(null)
-											setActiveEmojiKeyboardCid(inte.cid)
-										}}
-										onSelectEmoji={emoji => {
-											client
-												?.interact({
-													conversationPublicKey: convPK,
-													type: beapi.messenger.AppMessage.Type.TypeUserReaction,
-													payload: beapi.messenger.AppMessage.UserReaction.encode({
-														emoji: emoji,
-														state: true,
-													}).finish(),
-													targetCid: inte?.cid,
-												})
-												.then(() => {
-													ctx.playSound('messageSent')
-													setActivePopoverCid(null)
-													setActiveEmojiKeyboardCid(null)
-												})
-												.catch((e: unknown) => {
-													console.warn('e sending message:', e)
-												})
-										}}
-									/>
-								</Popover>
+									<>
+										{!!inte.medias?.length && (
+											<View
+												style={[
+													isFollowedMessage && {
+														marginLeft: (AVATAR_SIZE + AVATAR_SPACE_RIGHT) * scaleSize,
+													},
+													previousMessage?.medias?.[0]?.mimeType
+														? margin.top.tiny
+														: margin.top.small,
+													nextMessage?.medias?.[0]?.mimeType
+														? margin.bottom.tiny
+														: margin.bottom.small,
+												]}
+											>
+												{(() => {
+													if (inte.medias[0]?.mimeType?.startsWith('image')) {
+														return (
+															<PictureMessage
+																medias={inte.medias}
+																onLongPress={togglePopover}
+																isHighlight={isHighlight}
+															/>
+														)
+													} else if (inte.medias[0]?.mimeType?.startsWith('audio')) {
+														return (
+															<AudioMessage
+																medias={inte.medias}
+																onLongPress={togglePopover}
+																isHighlight={isHighlight}
+																isMine={!!inte.isMine}
+															/>
+														)
+													} else {
+														return (
+															<FileMessage
+																medias={inte.medias}
+																onLongPress={togglePopover}
+																isHighlight={isHighlight}
+															/>
+														)
+													}
+												})()}
+											</View>
+										)}
+										{!!(!inte.medias?.length || inte.payload?.body) && (
+											<HyperlinkUserMessage
+												inte={inte}
+												msgBorderColor={msgBorderColor}
+												isFollowedMessage={isFollowedMessage}
+												msgBackgroundColor={msgBackgroundColor}
+												msgTextColor={msgTextColor}
+												isHighlight={isHighlight}
+											/>
+										)}
+									</>
+								</TouchableOpacity>
 							</Animated.View>
 						</PanGestureHandler>
-
-						{activePopoverCid === inte.cid && <Popover />}
-						{!!inte?.reactions?.length && !!messageLayoutWidth && (
-							<View
-								onLayout={event => {
-									setReactionLayoutWidth(event.nativeEvent.layout.width)
+						{/* {!!messageLayoutWidth && (
+							<Reactions
+								convPk={convPK}
+								reactions={inte.reactions || []}
+								cid={inte.cid!}
+								onEmojiKeyboard={() => {
+									show(<EmojiKeyboard conversationPublicKey={convPK} targetCid={inte.cid!} />)
 								}}
-								style={[
-									border.radius.large,
-									{
-										flexDirection: 'row',
-										backgroundColor: colors['input-background'],
-										borderRadius: 20,
-										borderWidth: 1,
-										borderColor: colors['negative-asset'],
-										paddingVertical: 2,
-										paddingHorizontal: 4,
-										position: 'absolute',
-										bottom: inte?.payload?.body ? 0 : 9,
-									},
-									getPositionStyleForReactionView(
-										messageLayoutWidth,
-										reactionLayoutWidth,
-										!!inte.isMine,
-									),
-								]}
-							>
-								{inte.reactions
-									.filter(({ emoji }) => typeof emoji === 'string')
-									.map(({ emoji }) => (
-										<Text key={emoji} style={{ marginHorizontal: 2, fontSize: 10 }}>
-											{getEmojiByName(emoji as string)}
-										</Text>
-									))}
-							</View>
-						)}
+								onRemoveEmoji={handleSelectEmoji}
+							/>
+						)} */}
 					</View>
 					{!isWithinCollapseDuration && (
 						<TimestampStatusUserMessage
@@ -599,7 +536,6 @@ export const UserMessage: React.FC<{
 							cmd={cmd}
 						/>
 					)}
-					{/*<Text>wtf</Text>*/}
 				</View>
 			</View>
 		</View>
