@@ -1,13 +1,12 @@
 import React from 'react'
 import { View } from 'react-native'
 
-import { useStyles } from '@berty-tech/styles'
-import { useThemeColor } from '@berty-tech/store/hooks'
-
-import Logo from '../main/1_berty_picto.svg'
+import Logo from '@berty/assets/logo/1_berty_picto.svg'
+import { useStyles } from '@berty/contexts/styles'
+import { useThemeColor } from '@berty/store/hooks'
 
 export const useStylesNotification = () => {
-	const [{ flex }] = useStyles()
+	const { flex } = useStyles()
 	return {
 		touchable: [flex.tiny, flex.direction.row, { paddingHorizontal: 10 }],
 		innerTouchable: [flex.direction.row, { padding: 15, flexGrow: 0, flexShrink: 1 }],
