@@ -1,7 +1,7 @@
 import React from 'react'
 import { SafeAreaView } from 'react-native-safe-area-context'
 
-import { useThemeColor } from '@berty-tech/store/hooks'
+import { useThemeColor } from '@berty/store/hooks'
 
 const OnboardingWrapper: React.FC = ({ children }) => {
 	const colors = useThemeColor()
