@@ -1,4 +1,5 @@
-import React, { useEffect, useState } from 'react'
+import { Icon } from '@ui-kitten/components'
+import React, { ReactNode, useEffect, useState } from 'react'
 import {
 	View,
 	TouchableOpacity,
@@ -8,17 +9,162 @@ import {
 	TextInput,
 	ScrollView,
 } from 'react-native'
-import { Text, Icon } from '@ui-kitten/components'
 
-import { useStyles } from '@berty-tech/styles'
-import { useThemeColor } from '@berty-tech/store/hooks'
-import { Toggle } from '@berty-tech/components/shared-components/Toggle'
+import { Toggle } from '@berty/components/shared-components/Toggle'
+import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
+import { useStyles } from '@berty/contexts/styles'
+import { useThemeColor } from '@berty/store/hooks'
+
+import { UnifiedText } from './UnifiedText'
+
+export const Section: React.FC<{}> = ({ children }) => {
+	const { margin, border, padding } = useStyles()
+	const colors = useThemeColor()
+	return (
+		<View style={[margin.top.large, padding.horizontal.medium]}>
+			<View
+				style={[
+					border.radius.medium,
+					{
+						flex: 1,
+						backgroundColor: colors['main-background'],
+					},
+				]}
+			>
+				{children}
+			</View>
+		</View>
+	)
+}
+
+export const ButtonSettingV2: React.FC<{
+	text: string
+	icon?: string | React.ReactNode
+	onPress?: (...args: any) => void
+	accessibilityLabel?: string
+	toggle?: {
+		enable: boolean
+		value?: boolean
+		action?: () => Promise<void>
+	}
+	oppositeNode?: string | React.ReactNode
+	color?: string
+	pack?: string
+	disabled?: boolean
+	last?: boolean
+}> = ({
+	text,
+	icon,
+	onPress,
+	color,
+	toggle,
+	oppositeNode = 'arrow-ios-forward',
+	pack,
+	disabled = false,
+	last = false,
+	accessibilityLabel,
+}) => {
+	const { padding, margin, opacity } = useStyles()
+	const { scaleSize } = useAppDimensions()
+	const colors = useThemeColor()
+
+	if (!color) {
+		color = colors['background-header']
+	}
+	const heightButton = 55
+	const disabledOpacity = 0.3
+
+	if (toggle?.enable) {
+		oppositeNode = (
+			<Toggle
+				style={padding.right.scale(5)}
+				status='primary'
+				checked={toggle?.value}
+				onChange={async () => {
+					if (toggle && toggle?.action) {
+						await toggle?.action()
+					}
+				}}
+			/>
+		)
+	} else if (!React.isValidElement(oppositeNode) && oppositeNode) {
+		oppositeNode = (
+			<Icon
+				name={oppositeNode as string}
+				width={20 * scaleSize}
+				height={20 * scaleSize}
+				fill={colors['main-text']}
+			/>
+		)
+	}
+
+	if (!React.isValidElement(icon) && icon) {
+		icon = (
+			<Icon
+				name={icon as string}
+				width={20 * scaleSize}
+				height={20 * scaleSize}
+				pack={pack}
+				fill={color}
+			/>
+		)
+	}
+
+	return (
+		<>
+			<TouchableOpacity
+				onPress={!disabled ? onPress : () => {}}
+				activeOpacity={disabled ? disabledOpacity : 0.2}
+				accessibilityLabel={accessibilityLabel}
+				style={[
+					padding.vertical.medium,
+					padding.horizontal.medium,
+					disabled && opacity(disabledOpacity),
+					{
+						height: heightButton * scaleSize,
+						flexDirection: 'row',
+						alignItems: 'center',
+						justifyContent: 'space-between',
+					},
+				]}
+			>
+				<View style={{ flexDirection: 'row', alignItems: 'center' }}>
+					{icon}
+					<View
+						style={[
+							margin.left.small,
+							{ height: heightButton, flexDirection: 'row', alignItems: 'center' },
+						]}
+					>
+						<UnifiedText>{text}</UnifiedText>
+					</View>
+				</View>
+				{oppositeNode}
+			</TouchableOpacity>
+			{!last && (
+				<View style={{ flex: 1, height: 1, backgroundColor: colors['secondary-background'] }} />
+			)}
+		</>
+	)
+}
 
 //
 // Button Setting
 //
 
 // Type
+
+export type SettingButtonStateType = {
+	value: string
+	color: string
+	bgColor: string
+	icon?: string
+	iconSize?: number
+	iconColor?: string
+	stateIcon?: string
+	stateIconColor?: string
+}
+
 type SettingButtonProps = {
 	name: string
 	color?: string
@@ -30,19 +176,11 @@ type SettingButtonProps = {
 	iconPack?: string
 	iconDependToggle?: boolean
 	children?: React.ReactNode
-	state?: {
-		value: string
-		color: string
-		bgColor: string
-		icon?: string
-		iconSize?: number
-		iconColor?: string
-		stateIcon?: string
-		stateIconColor?: string
-	}
+	state?: SettingButtonStateType
 	alone?: boolean
 	toggled?: boolean
 	actionIcon?: string | null
+	actionIconAngle?: Animated.AnimatedInterpolation | null
 	actionIconSize?: number
 	actionIconColor?: string
 	actionToggle?: any
@@ -55,13 +193,13 @@ type SettingButtonProps = {
 	previewValue?: string
 	previewValueColor?: string
 	onPress?: (...args: any) => void
-	//
 	disabled?: boolean
+	rightComponent?: ReactNode
 }
 
 // Style
 const useStylesSettingButton = () => {
-	const [{ padding, margin }] = useStyles()
+	const { padding, margin } = useStyles()
 	return {
 		statePaddingBox: [padding.vertical.tiny, padding.horizontal.small],
 		descBox: [margin.left.scale(20), margin.bottom.medium],
@@ -82,6 +220,7 @@ export const ButtonSetting: React.FC<SettingButtonProps> = ({
 	state = {},
 	actionIconColor,
 	actionIconSize = 25,
+	actionIconAngle = null,
 	actionToggle = null,
 	varToggle = null,
 	toggleStatus = 'primary',
@@ -95,11 +234,12 @@ export const ButtonSetting: React.FC<SettingButtonProps> = ({
 	actionIcon = !toggled && 'arrow-ios-forward',
 	onPress,
 	disabled = false,
+	rightComponent,
 }) => {
 	const [isToggle, setIsToggle] = useState<boolean>()
 	const _styles = useStylesSettingButton()
-	const [{ margin, row, flex, padding, opacity, text, border }, { windowWidth, scaleSize }] =
-		useStyles()
+	const { margin, row, flex, padding, opacity, text, border } = useStyles()
+	const { windowWidth, scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 
 	if (!iconColor) {
@@ -130,13 +270,13 @@ export const ButtonSetting: React.FC<SettingButtonProps> = ({
 					: 0.2
 			}
 			style={[
-				style,
 				{ minHeight: 60 * scaleSize, backgroundColor, flex: 1 },
 				alone ? border.radius.medium : null,
 				alone ? border.shadow.medium : null,
 				alone ? { shadowColor: colors.shadow } : null,
 				alone ? margin.top.scale(20) : null,
 				disabled ? opacity(0.5) : opacity(1),
+				style,
 			]}
 			onPress={onPress}
 		>
@@ -170,7 +310,7 @@ export const ButtonSetting: React.FC<SettingButtonProps> = ({
 						<View>{/*<CircleAvatar avatarUri={image} withCircle={false} size={35} />*/}</View>
 					)}
 					<View>
-						<Text
+						<UnifiedText
 							numberOfLines={2}
 							style={[
 								padding.left.small,
@@ -180,7 +320,7 @@ export const ButtonSetting: React.FC<SettingButtonProps> = ({
 							]}
 						>
 							{name}
-						</Text>
+						</UnifiedText>
 					</View>
 				</View>
 				<View style={[row.center, { alignItems: 'center' }]}>
@@ -212,33 +352,31 @@ export const ButtonSetting: React.FC<SettingButtonProps> = ({
 										fill={state.stateIconColor}
 									/>
 								)}
-								<Text
-									style={[
-										text.align.center,
-										text.size.tiny,
-										text.bold.medium,
-										{ color: state.color },
-									]}
+								<UnifiedText
+									style={[text.align.center, text.size.tiny, text.bold, { color: state.color }]}
 								>
 									{state.value}
-								</Text>
+								</UnifiedText>
 							</View>
 						</View>
 					) : null}
 					{previewValue && (
 						<View>
-							<Text style={[padding.right.small, text.bold.medium, { color: previewValueColor }]}>
+							<UnifiedText style={[padding.right.small, text.bold, { color: previewValueColor }]}>
 								{previewValue}
-							</Text>
+							</UnifiedText>
 						</View>
 					)}
+					{rightComponent}
 					{actionIcon && (
-						<Icon
-							name={actionIcon}
-							width={actionIconSize}
-							height={actionIconSize}
-							fill={actionIconColor}
-						/>
+						<Animated.View style={actionIconAngle && { transform: [{ rotateZ: actionIconAngle }] }}>
+							<Icon
+								name={actionIcon}
+								width={actionIconSize}
+								height={actionIconSize}
+								fill={actionIconColor}
+							/>
+						</Animated.View>
 					)}
 					{toggled && (
 						<Toggle
@@ -255,7 +393,6 @@ export const ButtonSetting: React.FC<SettingButtonProps> = ({
 					)}
 				</View>
 			</View>
-			{children && <View style={[_styles.descBox]}>{children}</View>}
 		</TouchableOpacity>
 	)
 }
@@ -301,7 +438,8 @@ export const FactionButtonSetting: React.FC<FactionButtonSettingProps> = ({
 	isDropdown = false,
 }) => {
 	const _styles = useStylesSettingButton()
-	const [{ border, padding, flex, height, row, opacity, margin, text }, { scaleSize }] = useStyles()
+	const { border, padding, flex, height, row, opacity, margin, text } = useStyles()
+	const { scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 	const [isCollapse, setIsCollapse] = React.useState<boolean>(true)
 
@@ -341,7 +479,7 @@ export const FactionButtonSetting: React.FC<FactionButtonSettingProps> = ({
 								</View>
 							)}
 							<View>
-								<Text style={[padding.left.small, text.size.medium]}>{name}</Text>
+								<UnifiedText style={[padding.left.small, text.size.medium]}>{name}</UnifiedText>
 							</View>
 						</View>
 						<View>
@@ -379,16 +517,11 @@ export const FactionButtonSetting: React.FC<FactionButtonSettingProps> = ({
 												fill={state.stateIconColor}
 											/>
 										)}
-										<Text
-											style={[
-												row.item.justify,
-												text.size.tiny,
-												text.bold.medium,
-												{ color: state.color },
-											]}
+										<UnifiedText
+											style={[row.item.justify, text.size.tiny, text.bold, { color: state.color }]}
 										>
 											{state.value}
-										</Text>
+										</UnifiedText>
 									</View>
 								</View>
 							)}
@@ -481,6 +614,7 @@ type ButtonSettingRowProps = {
 		style: StyleProp<any>
 		onPress?: () => void
 		disabled?: boolean
+		displayComponent?: ReactNode
 	}[]
 	numberOfLines?: number
 	style?: StyleProp<any>
@@ -490,7 +624,7 @@ type ButtonSettingRowProps = {
 
 // Styles
 const useStylesButtonSettingRow = () => {
-	const [{ padding }] = useStyles()
+	const { padding } = useStyles()
 	return {
 		textPadding: padding.top.scale(6),
 	}
@@ -504,7 +638,7 @@ export const ButtonSettingRow: React.FC<ButtonSettingRowProps> = ({
 	isScroll = false,
 }) => {
 	const _styles = useStylesButtonSettingRow()
-	const [{ flex, row, margin, padding, border, text, opacity }] = useStyles()
+	const { flex, row, margin, padding, border, text, opacity, width } = useStyles()
 	const colors = useThemeColor()
 
 	return (
@@ -526,10 +660,10 @@ export const ButtonSettingRow: React.FC<ButtonSettingRowProps> = ({
 					key={key}
 					activeOpacity={obj.disabled ? 0.5 : undefined}
 					style={[
-						flex.tiny,
 						padding.medium,
 						border.radius.medium,
 						border.shadow.medium,
+						width(100),
 						obj.style,
 						obj.disabled ? opacity(0.5) : null,
 						{
@@ -537,24 +671,23 @@ export const ButtonSettingRow: React.FC<ButtonSettingRowProps> = ({
 							justifyContent: 'center',
 							backgroundColor: colors['main-background'],
 							shadowColor: colors.shadow,
-							width: 100,
 						},
 					]}
 					onPress={obj.onPress}
 				>
-					<Icon name={obj.icon} width={30} height={30} fill={obj.color} />
-					<Text
-						style={[
-							text.align.center,
-							text.size.medium,
-							styleText,
-							_styles.textPadding,
-							{ color: colors['main-text'] },
-						]}
-						numberOfLines={numberOfLines}
-					>
-						{obj.name}
-					</Text>
+					{obj.displayComponent ? (
+						obj.displayComponent
+					) : (
+						<>
+							<Icon name={obj.icon} width={30} height={30} fill={obj.color} />
+							<UnifiedText
+								style={[text.align.center, text.size.medium, styleText, _styles.textPadding]}
+								numberOfLines={numberOfLines}
+							>
+								{obj.name}
+							</UnifiedText>
+						</>
+					)}
 				</TouchableOpacity>
 			))}
 		</ScrollView>
@@ -579,9 +712,9 @@ type ButtonSettingItem = {
 
 // Styles
 const useStylesButtonSettingItem = () => {
-	const [{ text, padding }] = useStyles()
+	const { text, padding } = useStyles()
 	return {
-		updateFeatureText: [text.size.scale(11), padding.left.scale(8)],
+		updateFeatureText: [text.size.tiny, padding.left.scale(8)],
 	}
 }
 
@@ -595,7 +728,7 @@ export const ButtonSettingItem: React.FC<ButtonSettingItem> = ({
 	styleText = {},
 }) => {
 	const _styles = useStylesButtonSettingItem()
-	const [{ row, padding, text }] = useStyles()
+	const { row, padding, text } = useStyles()
 	const colors = useThemeColor()
 
 	if (!color) {
@@ -609,16 +742,17 @@ export const ButtonSettingItem: React.FC<ButtonSettingItem> = ({
 				height={iconSize}
 				fill={iconColor || colors['positive-asset']}
 			/>
-			<Text style={[text.bold.medium, _styles.updateFeatureText, { color }, styleText]}>
+			<UnifiedText style={[text.bold, _styles.updateFeatureText, { color }, styleText]}>
 				{value}
-			</Text>
+			</UnifiedText>
 		</View>
 	)
 }
 
 export const ButtonDropDown: React.FC<{ title: string; body: string }> = ({ title, body }) => {
 	const [isOpen, setOpen] = useState(false)
-	const [{ padding, margin, text }, { scaleSize }] = useStyles()
+	const { padding, margin, text } = useStyles()
+	const { scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 
 	const [animateHeight] = useState(new Animated.Value(0))
@@ -640,9 +774,9 @@ export const ButtonDropDown: React.FC<{ title: string; body: string }> = ({ titl
 			}}
 		>
 			<View style={[padding.right.small, { flex: 1, overflow: 'hidden' }]}>
-				<Text style={[{ marginBottom: 12 }, text.size.medium]}>{title}</Text>
+				<UnifiedText style={[{ marginBottom: 12 }, text.size.medium]}>{title}</UnifiedText>
 				<Animated.View style={{ maxHeight: animateHeight }}>
-					<Text style={[margin.top.small, text.size.medium]}>{body}</Text>
+					<UnifiedText style={[margin.top.small, text.size.medium]}>{body}</UnifiedText>
 				</Animated.View>
 			</View>
 			<TouchableOpacity
@@ -686,7 +820,8 @@ export const StringOptionInput: React.FC<{
 	bulletPointValue?: string
 	iconColor?: string | undefined
 }> = ({ name, bulletPointValue, getOptionValue, setOptionValue, iconColor }) => {
-	const [{ flex, row, text, margin, padding, border }, { scaleSize }] = useStyles()
+	const { flex, row, text, margin, padding, border } = useStyles()
+	const { scaleSize } = useAppDimensions()
 	const [value, setValue] = useState('')
 	useEffect(() => {
 		;(async () => {
@@ -728,7 +863,7 @@ export const StringOptionInput: React.FC<{
 						onChangeText={t => setValue(t)}
 						value={value}
 						style={[
-							text.bold.small,
+							text.light,
 							text.size.medium,
 							flex.scale(8),
 							{
