@@ -1,33 +1,35 @@
-import React, { useCallback, useEffect, useState } from 'react'
-import { Linking } from 'react-native'
-import { useTranslation } from 'react-i18next'
+import { CommonActions, NavigationProp, useNavigation } from '@react-navigation/native'
 import {
 	createNativeStackNavigator,
 	NativeStackNavigationOptions,
 } from '@react-navigation/native-stack'
-import { CommonActions, NavigationProp, useNavigation } from '@react-navigation/native'
 import { Icon } from '@ui-kitten/components'
 import mapValues from 'lodash/mapValues'
-
-import * as RawComponents from '@berty-tech/components'
-import { useMessengerContext, useThemeColor } from '@berty-tech/store'
-import { useStyles } from '@berty-tech/styles'
-
-import { dispatch } from './rootRef'
-import { ScreensParams } from './types'
+import React, { useCallback, useEffect, useState } from 'react'
+import { useTranslation } from 'react-i18next'
+import { Linking, Platform, TouchableOpacity } from 'react-native'
 import { useSelector } from 'react-redux'
-import { MESSENGER_APP_STATE, selectAppState } from '@berty-tech/redux/reducers/ui.reducer'
+
+import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
+import { useStyles } from '@berty/contexts/styles'
+import { useAppDispatch } from '@berty/hooks'
+import { selectHandledLink, setHandledLink } from '@berty/redux/reducers/ui.reducer'
+import * as RawComponents from '@berty/screens'
+import { useThemeColor } from '@berty/store'
+
+import { ScreensParams } from './types'
 
 export const CustomTitleStyle: () => any = () => {
-	const [{}, { scaleSize }] = useStyles()
+	const { text } = useStyles()
 
-	return {
-		headerTitleStyle: {
-			fontFamily: 'Open Sans',
-			fontWeight: '700',
-			fontSize: 20 * scaleSize,
+	return [
+		text.size.large,
+		{
+			headerTitleStyle: {
+				...text.bold,
+			},
 		},
-	}
+	]
 }
 
 const ChatScreenOptions: (
@@ -60,21 +62,6 @@ const BackgroundHeaderScreenOptions: (
 	}
 }
 
-const SecondaryBackgroundHeaderScreenOptions: (
-	additionalProps?: NativeStackNavigationOptions,
-) => NativeStackNavigationOptions = additionalProps => {
-	const colors = useThemeColor()
-	return {
-		headerStyle: {
-			backgroundColor: colors['secondary-background-header'],
-		},
-		headerTintColor: colors['reverted-main-text'],
-		headerBackTitleVisible: false,
-		headerShadowVisible: false,
-		...additionalProps,
-	}
-}
-
 const AltBackgroundHeaderScreenOptions: (
 	additionalProps?: NativeStackNavigationOptions,
 ) => NativeStackNavigationOptions = additionalProps => {
@@ -126,14 +113,15 @@ function useLinking(): [string | null, unknown] {
 const DeepLinkBridge: React.FC = React.memo(() => {
 	const [url, error] = useLinking()
 	const navigation = useNavigation<NavigationProp<ScreensParams>>()
-	const ctx = useMessengerContext()
+	const dispatch = useAppDispatch()
+	const handledLink = useSelector(selectHandledLink)
 
 	useEffect(() => {
-		if (!ctx.handledLink && url && !error && !(url as string).startsWith('berty://services-auth')) {
-			ctx.setHandledLink(true)
-			navigation.navigate('Modals.ManageDeepLink', { type: 'link', value: url })
+		if (!handledLink && url && !error && !(url as string).startsWith('berty://services-auth')) {
+			dispatch(setHandledLink(true))
+			navigation.navigate('Chat.ManageDeepLink', { type: 'link', value: url })
 		}
-	}, [ctx, error, navigation, url])
+	}, [dispatch, handledLink, error, navigation, url])
 
 	return null
 })
@@ -147,7 +135,7 @@ Components = mapValues(RawComponents, SubComponents =>
 		(Component: React.FC): React.FC =>
 			React.memo(props => (
 				<>
-					<DeepLinkBridge />
+					{Platform.OS !== 'web' ? <DeepLinkBridge /> : null}
 					<Component {...props} />
 				</>
 			)),
@@ -157,133 +145,211 @@ Components = mapValues(RawComponents, SubComponents =>
 const NavigationStack = createNativeStackNavigator<ScreensParams>()
 
 export const Navigation: React.FC = React.memo(() => {
-	const appState = useSelector(selectAppState)
 	const colors = useThemeColor()
-	const [, { scaleSize }] = useStyles()
+	const { scaleSize } = useAppDimensions()
 	const { t }: any = useTranslation()
-
-	useEffect(() => {
-		console.log('context app State', appState)
-		switch (appState) {
-			case MESSENGER_APP_STATE.READY:
-				dispatch(
-					CommonActions.reset({
-						routes: [{ name: 'Main.Home' }],
-					}),
-				)
-				return
-			case MESSENGER_APP_STATE.PRE_READY:
-				dispatch(
-					CommonActions.reset({
-						routes: [{ name: 'Onboarding.SetupFinished' }],
-					}),
-				)
-				return
-		}
-	}, [appState])
+	const { dispatch } = useNavigation()
 
 	return (
 		<NavigationStack.Navigator
-			initialRouteName={
-				appState === MESSENGER_APP_STATE.GET_STARTED ? 'Onboarding.GetStarted' : 'Main.Home'
-			}
+			initialRouteName='Account.InitialLaunch'
+			screenOptions={{
+				headerLeft:
+					Platform.OS === 'web'
+						? props => (
+								<TouchableOpacity
+									style={{ justifyContent: 'center' }}
+									onPress={() => dispatch(CommonActions.goBack())}
+								>
+									<Icon name='arrow-back' width={24} height={24} fill={props.tintColor} />
+								</TouchableOpacity>
+						  )
+						: undefined,
+			}}
 		>
+			{/* Account */}
+			<NavigationStack.Screen
+				name={'Account.InitialLaunch'}
+				component={Components.Account.InitialLaunch}
+				options={{ headerShown: false }}
+			/>
+			<NavigationStack.Screen
+				name={'Account.Creating'}
+				component={Components.Account.CreatingAccount}
+				options={{ headerShown: false }}
+			/>
+			<NavigationStack.Screen
+				name={'Account.Opening'}
+				component={Components.Account.OpeningAccount}
+				options={{ headerShown: false }}
+			/>
+			<NavigationStack.Screen
+				name={'Account.Closing'}
+				component={Components.Account.ClosingAccount}
+				options={{ headerShown: false }}
+			/>
+			<NavigationStack.Screen
+				name={'Account.Importing'}
+				component={Components.Account.ImportingAccount}
+				options={{ headerShown: false }}
+			/>
+			<NavigationStack.Screen
+				name={'Account.Deleting'}
+				component={Components.Account.DeletingAccount}
+				options={{ headerShown: false }}
+			/>
 			{/* OnBoarding */}
 			<NavigationStack.Screen
 				name={'Onboarding.GetStarted'}
 				component={Components.Onboarding.GetStarted}
-				options={{ headerShown: false }}
+				options={{ headerShown: false, title: t('onboarding.getstarted.screenTitle') }}
 			/>
 			<NavigationStack.Screen
 				name={'Onboarding.CreateAccount'}
 				component={Components.Onboarding.CreateAccount}
-				options={{ headerShown: false }}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['background-header'],
+					},
+					headerTintColor: colors['reverted-main-text'],
+					headerBackTitleVisible: false,
+					title: t('onboarding.getstarted.create-button'),
+					headerTitle: () => <></>,
+				}}
 			/>
 			<NavigationStack.Screen
 				name={'Onboarding.SetupFinished'}
 				component={Components.Onboarding.SetupFinished}
-				options={{ headerShown: false }}
+				options={{ headerShown: false, title: t('onboarding.setup-finished.title') }}
 			/>
 			<NavigationStack.Screen
-				name={'Onboarding.AdvancedSettings'}
-				component={Components.Onboarding.AdvancedSettings}
-				options={{ headerShown: false }}
+				name={'Onboarding.CustomModeSettings'}
+				component={Components.Onboarding.CustomModeSettings}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['background-header'],
+					},
+					headerTintColor: colors['reverted-main-text'],
+					headerBackTitleVisible: false,
+					title: t('onboarding.custom-mode.summary.screenTitle'),
+					headerTitle: () => <></>,
+				}}
 			/>
 			<NavigationStack.Screen
 				name={'Onboarding.WebViews'}
 				component={Components.Onboarding.WebViews}
-				options={{ title: '', headerBackTitle: '', headerTintColor: colors['main-text'] }}
-			/>
-			{/* Main */}
-			<NavigationStack.Screen
-				name={'Main.Home'}
-				component={Components.Main.Home}
-				options={{ headerShown: false }}
+				options={{
+					title: t('onboarding.web-views.title'),
+					headerTitle: () => <></>,
+					headerBackTitle: '',
+					headerTintColor: colors['main-text'],
+				}}
 			/>
 			<NavigationStack.Screen
-				name={'Main.ContactRequest'}
-				component={Components.Main.ContactRequest}
+				name={'Onboarding.DefaultMode'}
+				component={Components.Onboarding.DefaultMode}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['background-header'],
+					},
+					headerTintColor: colors['reverted-main-text'],
+					headerBackTitleVisible: false,
+					title: t('onboarding.default-mode.summary.screenTitle'),
+					headerTitle: () => <></>,
+				}}
 			/>
 			<NavigationStack.Screen
-				name={'Main.Scan'}
-				component={Components.Main.Scan}
-				options={SecondaryBackgroundHeaderScreenOptions({
-					title: t('main.scan.title'),
-					headerRight: () => (
-						<Icon
-							name='qr'
-							pack='custom'
-							width={35 * scaleSize}
-							height={35 * scaleSize}
-							fill={colors['reverted-main-text']}
-						/>
-					),
-					presentation: 'formSheet',
-				})}
-			/>
-			<NavigationStack.Screen
-				name={'Main.Permissions'}
-				component={Components.Main.Permissions}
-				options={{ headerShown: false, presentation: 'formSheet' }}
-			/>
-			{/* CreateGroup */}
-			<NavigationStack.Screen
-				name={'Main.CreateGroupAddMembers'}
-				component={Components.Main.CreateGroupAddMembers}
-				options={BackgroundHeaderScreenOptions({
-					title: t('main.home.create-group.title'),
-					headerRight: () => (
-						<Icon
-							name='users'
-							pack='custom'
-							width={35 * scaleSize}
-							height={35 * scaleSize}
-							fill={colors['reverted-main-text']}
-						/>
-					),
-					...CustomTitleStyle(),
-					presentation: 'formSheet',
-				})}
-			/>
-			<NavigationStack.Screen
-				name={'Main.CreateGroupFinalize'}
-				component={Components.Main.CreateGroupFinalize}
-				options={BackgroundHeaderScreenOptions({
-					title: t('main.home.create-group.title'),
-					headerRight: () => (
-						<Icon
-							name='users'
-							pack='custom'
-							width={35 * scaleSize}
-							height={35 * scaleSize}
-							fill={colors['reverted-main-text']}
-						/>
-					),
-					...CustomTitleStyle(),
-					presentation: 'formSheet',
-				})}
+				name={'Onboarding.CustomMode'}
+				component={Components.Onboarding.CustomMode}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['background-header'],
+					},
+					headerTintColor: colors['reverted-main-text'],
+					headerBackTitleVisible: false,
+					title: t('onboarding.custom-mode.summary.screenTitle'),
+					headerTitle: () => <></>,
+				}}
 			/>
 			{/* Chat */}
+			<NavigationStack.Screen
+				name={'Chat.Home'}
+				component={Components.Chat.Home}
+				options={{
+					headerShown: false,
+					title: t('main.home.title'),
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Chat.ContactRequest'}
+				component={Components.Chat.ContactRequest}
+				options={{
+					headerShown: false,
+					title: t('main.home.requests.page-title'),
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Chat.Permissions'}
+				component={Components.Chat.Permissions}
+				options={{
+					headerShown: false,
+					presentation: 'formSheet',
+					title: t('permission.request.title'),
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Chat.NotificationAndProximityPermissions'}
+				component={Components.Chat.NotificationAndProximityPermissions}
+				options={{
+					headerShown: false,
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Chat.Share'}
+				component={Components.Chat.ShareModal}
+				options={BackgroundHeaderScreenOptions({
+					title: t('main.home.title'),
+					headerTitle: () => <></>,
+					presentation: 'formSheet',
+				})}
+			/>
+			<NavigationStack.Screen
+				name={'Chat.CreateGroupAddMembers'}
+				component={Components.Chat.CreateGroupAddMembers}
+				options={BackgroundHeaderScreenOptions({
+					title: t('main.home.create-group.title'),
+					headerRight: () => (
+						<Icon
+							name='users'
+							pack='custom'
+							width={35 * scaleSize}
+							height={35 * scaleSize}
+							fill={colors['reverted-main-text']}
+						/>
+					),
+					presentation: 'formSheet',
+					...CustomTitleStyle(),
+				})}
+			/>
+			<NavigationStack.Screen
+				name={'Chat.CreateGroupFinalize'}
+				component={Components.Chat.CreateGroupFinalize}
+				options={BackgroundHeaderScreenOptions({
+					title: t('main.home.create-group.title'),
+					headerRight: () => (
+						<Icon
+							name='users'
+							pack='custom'
+							width={35 * scaleSize}
+							height={35 * scaleSize}
+							fill={colors['reverted-main-text']}
+						/>
+					),
+					...CustomTitleStyle(),
+					presentation: 'formSheet',
+				})}
+			/>
 			<NavigationStack.Screen
 				name={'Chat.OneToOne'}
 				component={Components.Chat.OneToOne}
@@ -302,7 +368,8 @@ export const Navigation: React.FC = React.memo(() => {
 				name={'Chat.OneToOneSettings'}
 				component={Components.Chat.OneToOneSettings}
 				options={BackgroundHeaderScreenOptions({
-					title: '',
+					title: t('chat.one-to-one-settings.title'),
+					headerTitle: () => <></>,
 					presentation: 'formSheet',
 				})}
 			/>
@@ -310,7 +377,8 @@ export const Navigation: React.FC = React.memo(() => {
 				name={'Chat.ContactSettings'}
 				component={Components.Chat.ContactSettings}
 				options={BackgroundHeaderScreenOptions({
-					title: '',
+					title: t('chat.one-to-one-settings.title'),
+					headerTitle: () => <></>,
 					presentation: 'formSheet',
 				})}
 			/>
@@ -318,7 +386,8 @@ export const Navigation: React.FC = React.memo(() => {
 				name={'Group.MultiMemberSettings'}
 				component={Components.Chat.MultiMemberSettings}
 				options={BackgroundHeaderScreenOptions({
-					title: '',
+					title: t('chat.multi-member-settings.title'),
+					headerTitle: () => <></>,
 					presentation: 'formSheet',
 				})}
 			/>
@@ -326,7 +395,8 @@ export const Navigation: React.FC = React.memo(() => {
 				name={'Group.ChatSettingsMemberDetail'}
 				component={Components.Chat.ChatSettingsMemberDetail}
 				options={BackgroundHeaderScreenOptions({
-					title: '',
+					title: t('chat.multi-member-settings.title'),
+					headerTitle: () => <></>,
 					presentation: 'formSheet',
 				})}
 			/>
@@ -340,7 +410,7 @@ export const Navigation: React.FC = React.memo(() => {
 				})}
 			/>
 			<NavigationStack.Screen
-				name={'Group.MultiMemberSettingsAddMembers'}
+				name={'Chat.MultiMemberSettingsAddMembers'}
 				component={Components.Chat.MultiMemberSettingsAddMembers}
 				options={BackgroundHeaderScreenOptions({
 					title: t('chat.add-members.members'),
@@ -369,10 +439,118 @@ export const Navigation: React.FC = React.memo(() => {
 			{/* Settings */}
 			<NavigationStack.Screen
 				name={'Settings.Home'}
-				component={Components.Settings.Home}
-				options={BackgroundHeaderScreenOptions({
-					title: '',
-				})}
+				component={Components.Settings.SettingsHome}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+
+					headerTintColor: colors['main-text'],
+					headerBackTitleVisible: false,
+					title: t('settings.home.title'),
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.Network'}
+				component={Components.Settings.Network}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					headerTintColor: colors['main-text'],
+					headerBackTitleVisible: false,
+					title: t('settings.network.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.Notifications'}
+				component={Components.Settings.Notifications}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.notifications.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.ContactAndConversations'}
+				component={Components.Settings.ContactAndConversations}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.contact-convs.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.Appearance'}
+				component={Components.Settings.Appearance}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.appearance.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.ThemeEditor'}
+				component={Components.Settings.ThemeEditor}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['alt-secondary-background-header'],
+					},
+					headerTintColor: colors['reverted-main-text'],
+					title: t('settings.appearance.theme-editor.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.DevicesAndBackup'}
+				component={Components.Settings.DevicesAndBackup}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.devices-backup.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.Security'}
+				component={Components.Settings.Security}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.security.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.Accounts'}
+				component={Components.Settings.Accounts}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.accounts.title'),
+					presentation: 'formSheet',
+				}}
+			/>
+			<NavigationStack.Screen
+				name={'Settings.AboutBerty'}
+				component={Components.Settings.AboutBerty}
+				options={{
+					headerStyle: {
+						backgroundColor: colors['secondary-background'],
+					},
+					title: t('settings.about.title'),
+					presentation: 'formSheet',
+				}}
 			/>
 			<NavigationStack.Screen
 				name={'Settings.MyBertyId'}
@@ -383,32 +561,15 @@ export const Navigation: React.FC = React.memo(() => {
 					presentation: 'formSheet',
 				})}
 			/>
-			<NavigationStack.Screen
-				name={'Settings.AboutBerty'}
-				component={Components.Settings.AboutBerty}
-				options={BackgroundHeaderScreenOptions({
-					title: t('settings.about.title'),
-					...CustomTitleStyle(),
-					presentation: 'formSheet',
-				})}
-			/>
 			<NavigationStack.Screen
 				name={'Settings.TermsOfUse'}
 				component={Components.Settings.TermsOfUse}
 				options={BackgroundHeaderScreenOptions({
-					title: 'Terms of use',
+					title: t('settings.about.terms-of-use'),
 					...CustomTitleStyle(),
 					presentation: 'formSheet',
 				})}
 			/>
-			<NavigationStack.Screen
-				name={'Settings.Mode'}
-				component={Components.Settings.Mode}
-				options={BackgroundHeaderScreenOptions({
-					title: t('settings.mode.title'),
-					...CustomTitleStyle(),
-				})}
-			/>
 			<NavigationStack.Screen
 				name={'Settings.NetworkMap'}
 				component={Components.Settings.NetworkMap}
@@ -433,6 +594,7 @@ export const Navigation: React.FC = React.memo(() => {
 				options={{
 					headerShown: false,
 					presentation: 'formSheet',
+					title: t('settings.accounts.delete-title'),
 				}}
 			/>
 			<NavigationStack.Screen
@@ -453,14 +615,7 @@ export const Navigation: React.FC = React.memo(() => {
 					presentation: 'formSheet',
 				})}
 			/>
-			<NavigationStack.Screen
-				name={'Settings.ThemeEditor'}
-				component={Components.Settings.ThemeEditor}
-				options={AltBackgroundHeaderScreenOptions({
-					title: t('settings.theme-editor.title'),
-					...CustomTitleStyle(),
-				})}
-			/>
+
 			<NavigationStack.Screen
 				name={'Settings.SystemInfo'}
 				component={Components.Settings.SystemInfo}
@@ -499,7 +654,11 @@ export const Navigation: React.FC = React.memo(() => {
 			<NavigationStack.Screen
 				name={'Settings.BertyServices'}
 				component={Components.Settings.BertyServices}
-				options={{ headerShown: false, presentation: 'formSheet' }}
+				options={{
+					headerShown: false,
+					presentation: 'formSheet',
+					title: t('settings.berty-services.title'),
+				}}
 			/>
 			<NavigationStack.Screen
 				name={'Settings.Roadmap'}
@@ -519,10 +678,18 @@ export const Navigation: React.FC = React.memo(() => {
 					presentation: 'formSheet',
 				})}
 			/>
-			{/* Modals */}
 			<NavigationStack.Screen
-				name={'Modals.ManageDeepLink'}
-				component={Components.Modals.ManageDeepLink}
+				name={'Settings.PrivacyPolicy'}
+				component={Components.Settings.PrivacyPolicy}
+				options={BackgroundHeaderScreenOptions({
+					title: t('settings.privacy-policy.title'),
+					...CustomTitleStyle(),
+					presentation: 'formSheet',
+				})}
+			/>
+			<NavigationStack.Screen
+				name={'Chat.ManageDeepLink'}
+				component={Components.Chat.ManageDeepLink}
 				options={{
 					presentation: 'containedTransparentModal',
 					animation: 'fade',
@@ -531,21 +698,12 @@ export const Navigation: React.FC = React.memo(() => {
 			/>
 			<NavigationStack.Screen
 				name={'Modals.ImageView'}
-				component={Components.Modals.ImageView}
+				component={Components.Chat.ImageView}
 				options={{
 					presentation: 'containedTransparentModal',
 					headerShown: false,
 				}}
 			/>
-			<NavigationStack.Screen
-				name={'Modals.EditProfile'}
-				component={Components.Modals.EditProfile}
-				options={{
-					presentation: 'transparentModal',
-					headerShown: false,
-					animation: 'fade_from_bottom',
-				}}
-			/>
 		</NavigationStack.Navigator>
 	)
 })
