@@ -1,4 +1,4 @@
-import beapi from '@berty-tech/api'
+import beapi from '@berty/api'
 
 export type StreamEventPayloadType<T> = T extends beapi.messenger.StreamEvent.Type.Undefined
 	? undefined
@@ -130,6 +130,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.InstanceShareableBertyID.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useShareableBertyGroup: () => {
 		error: any
@@ -137,6 +138,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ShareableBertyGroup.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useDevShareInstanceBertyID: () => {
 		error: any
@@ -144,6 +146,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.DevShareInstanceBertyID.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useParseDeepLink: () => {
 		error: any
@@ -151,6 +154,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ParseDeepLink.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useSendContactRequest: () => {
 		error: any
@@ -158,6 +162,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.SendContactRequest.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useSendReplyOptions: () => {
 		error: any
@@ -165,6 +170,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.SendReplyOptions.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useSystemInfo: () => {
 		error: any
@@ -172,6 +178,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.SystemInfo.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useConversationCreate: () => {
 		error: any
@@ -179,6 +186,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ConversationCreate.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useConversationJoin: () => {
 		error: any
@@ -186,6 +194,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ConversationJoin.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useAccountGet: () => {
 		error: any
@@ -193,6 +202,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.AccountGet.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useAccountUpdate: () => {
 		error: any
@@ -200,6 +210,15 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.AccountUpdate.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
+	}
+	useAccountPushConfigure: () => {
+		error: any
+		call: (req?: beapi.messenger.AccountPushConfigure.IRequest) => void
+		reply: beapi.messenger.AccountPushConfigure.IReply | null
+		done: boolean
+		called: boolean
+		loading: boolean
 	}
 	useContactRequest: () => {
 		error: any
@@ -207,6 +226,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ContactRequest.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactAccept: () => {
 		error: any
@@ -214,6 +234,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ContactAccept.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useInteract: () => {
 		error: any
@@ -221,6 +242,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.Interact.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useConversationOpen: () => {
 		error: any
@@ -228,6 +250,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ConversationOpen.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useConversationClose: () => {
 		error: any
@@ -235,6 +258,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ConversationClose.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useConversationLoad: () => {
 		error: any
@@ -242,6 +266,15 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ConversationLoad.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
+	}
+	useConversationMute: () => {
+		error: any
+		call: (req?: beapi.messenger.ConversationMute.IRequest) => void
+		reply: beapi.messenger.ConversationMute.IReply | null
+		done: boolean
+		called: boolean
+		loading: boolean
 	}
 	useReplicationServiceRegisterGroup: () => {
 		error: any
@@ -249,6 +282,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ReplicationServiceRegisterGroup.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useReplicationSetAutoEnable: () => {
 		error: any
@@ -256,6 +290,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.ReplicationSetAutoEnable.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useBannerQuote: () => {
 		error: any
@@ -263,6 +298,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.BannerQuote.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMediaGetRelated: () => {
 		error: any
@@ -270,6 +306,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.MediaGetRelated.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMessageSearch: () => {
 		error: any
@@ -277,6 +314,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.MessageSearch.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useTyberHostAttach: () => {
 		error: any
@@ -284,6 +322,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.TyberHostAttach.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushSetAutoShare: () => {
 		error: any
@@ -291,6 +330,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.PushSetAutoShare.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushShareTokenForConversation: () => {
 		error: any
@@ -298,6 +338,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.PushShareTokenForConversation.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushReceive: () => {
 		error: any
@@ -305,6 +346,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.PushReceive.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useInteractionReactionsForEmoji: () => {
 		error: any
@@ -312,6 +354,7 @@ export type MessengerMethodsHooks = {
 		reply: beapi.messenger.InteractionReactionsForEmoji.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 }
 export type ProtocolMethodsHooks = {
@@ -321,6 +364,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.InstanceGetConfiguration.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactRequestReference: () => {
 		error: any
@@ -328,6 +372,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactRequestReference.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactRequestDisable: () => {
 		error: any
@@ -335,6 +380,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactRequestDisable.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactRequestEnable: () => {
 		error: any
@@ -342,6 +388,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactRequestEnable.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactRequestResetReference: () => {
 		error: any
@@ -349,6 +396,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactRequestResetReference.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactRequestSend: () => {
 		error: any
@@ -356,6 +404,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactRequestSend.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactRequestAccept: () => {
 		error: any
@@ -363,6 +412,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactRequestAccept.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactRequestDiscard: () => {
 		error: any
@@ -370,6 +420,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactRequestDiscard.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactBlock: () => {
 		error: any
@@ -377,6 +428,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactBlock.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactUnblock: () => {
 		error: any
@@ -384,6 +436,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactUnblock.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useContactAliasKeySend: () => {
 		error: any
@@ -391,6 +444,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ContactAliasKeySend.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMultiMemberGroupCreate: () => {
 		error: any
@@ -398,6 +452,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.MultiMemberGroupCreate.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMultiMemberGroupJoin: () => {
 		error: any
@@ -405,6 +460,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.MultiMemberGroupJoin.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMultiMemberGroupLeave: () => {
 		error: any
@@ -412,6 +468,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.MultiMemberGroupLeave.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMultiMemberGroupAliasResolverDisclose: () => {
 		error: any
@@ -419,6 +476,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.MultiMemberGroupAliasResolverDisclose.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMultiMemberGroupAdminRoleGrant: () => {
 		error: any
@@ -426,6 +484,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.MultiMemberGroupAdminRoleGrant.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useMultiMemberGroupInvitationCreate: () => {
 		error: any
@@ -433,6 +492,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.MultiMemberGroupInvitationCreate.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useAppMetadataSend: () => {
 		error: any
@@ -440,6 +500,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.AppMetadataSend.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useAppMessageSend: () => {
 		error: any
@@ -447,6 +508,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.AppMessageSend.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useGroupInfo: () => {
 		error: any
@@ -454,6 +516,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.GroupInfo.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useActivateGroup: () => {
 		error: any
@@ -461,6 +524,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ActivateGroup.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useDeactivateGroup: () => {
 		error: any
@@ -468,6 +532,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.DeactivateGroup.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useDebugGroup: () => {
 		error: any
@@ -475,6 +540,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.DebugGroup.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useDebugAuthServiceSetToken: () => {
 		error: any
@@ -482,6 +548,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.DebugAuthServiceSetToken.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useSystemInfo: () => {
 		error: any
@@ -489,6 +556,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.SystemInfo.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useAuthServiceInitFlow: () => {
 		error: any
@@ -496,6 +564,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.AuthServiceInitFlow.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useAuthServiceCompleteFlow: () => {
 		error: any
@@ -503,6 +572,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.AuthServiceCompleteFlow.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	useReplicationServiceRegisterGroup: () => {
 		error: any
@@ -510,6 +580,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.ReplicationServiceRegisterGroup.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePeerList: () => {
 		error: any
@@ -517,6 +588,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.PeerList.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushReceive: () => {
 		error: any
@@ -524,6 +596,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.PushReceive.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushSend: () => {
 		error: any
@@ -531,6 +604,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.PushSend.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushShareToken: () => {
 		error: any
@@ -538,6 +612,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.PushShareToken.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushSetDeviceToken: () => {
 		error: any
@@ -545,6 +620,7 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.PushSetDeviceToken.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 	usePushSetServer: () => {
 		error: any
@@ -552,5 +628,6 @@ export type ProtocolMethodsHooks = {
 		reply: beapi.protocol.PushSetServer.IReply | null
 		done: boolean
 		called: boolean
+		loading: boolean
 	}
 }
